@@ -79,6 +79,7 @@ class ContextMenuExtension;
  * X-KDE-PluginInfo-Author=
  * X-KDE-PluginInfo-Version=
  * X-KDE-PluginInfo-License=
+ * X-KDE-PluginInfo-Category=
  * X-KDevelop-Version=
  * X-KDevelop-Category=
  * X-KDevelop-Mode=GUI
@@ -105,6 +106,10 @@ class ContextMenuExtension;
  * - <i>X-KDE-PluginInfo-License</i> is a license (optional). can be: GPL,
  * LGPL, BSD, Artistic, QPL or Custom. If this property is not set, license is
  * considered as unknown;
+ * - <i>X-KDE-PluginInfo-Category</i> is used to categorize plugins (optional). can be:
+ *    Core, Project Management, Version Control, Utilities, Documentation,
+ *    Language Support, Debugging, Other
+ *   If this property is not set, "Other" is assumed
  * - <i>X-KDevelop-Version</i> is the KDevPlatform API version this plugin
  *   works with (required);
  * - <i>X-KDevelop-Interfaces</i> is a list of extension interfaces that this
@@ -213,6 +218,17 @@ public:
      * @param actions Add your actions here. A new set of actions has to be created for each mainwindow.
      */
     virtual void createActionsForMainWindow( Sublime::MainWindow* window, QString& xmlFile, KActionCollection& actions );
+
+    /**
+     * This function is necessary because there is no proper way to signal errors from plugin constructor.
+     * @returns True if the plugin has encountered an error, false otherwise.
+     */
+    virtual bool hasError() const;
+
+    /**
+     * Description of the last encountered error, of an empty string if none.
+     */
+    virtual QString errorDescription() const;
 public Q_SLOTS:
     /**
      * Re-initialize the global icon loader
