@@ -57,7 +57,7 @@ public:
     /// Returns a list of inheritances for the new class
     QStringList inheritanceList() const;
     
-    virtual bool validatePage(void);
+    virtual bool validatePage();
 
 Q_SIGNALS:
     void inheritanceChanged();
@@ -110,9 +110,9 @@ class KDEVPLATFORMLANGUAGE_EXPORT LicensePage : public QWizardPage
 
 public:
     LicensePage(QWizard* parent);
-    virtual ~LicensePage(void);
+    virtual ~LicensePage();
     
-    bool validatePage(void);
+    bool validatePage();
 
 public Q_SLOTS:
     virtual void licenseComboChanged(int license);
@@ -122,9 +122,9 @@ private:
     class LicensePagePrivate* const d;
     
     // methods
-    void        initializeLicenses(void);
+    void        initializeLicenses();
     QString &   readLicense(int licenseIndex);
-    bool        saveLicense(void);
+    bool        saveLicense();
 };
 
 /**
@@ -135,8 +135,8 @@ class KDEVPLATFORMLANGUAGE_EXPORT ClassGenerator
 {
   public:
     
-    ClassGenerator(void);
-    virtual ~ClassGenerator(void);
+    ClassGenerator();
+    virtual ~ClassGenerator();
       
     /**
      * Generate the actual DocumentChangeSet
@@ -146,12 +146,12 @@ class KDEVPLATFORMLANGUAGE_EXPORT ClassGenerator
     /**
      * Remove all previous base classes
      */
-    virtual void clearInheritance(void);
+    virtual void clearInheritance();
     
     /**
      * Clear all in class declarations
      */
-    void clearDeclarations(void);
+    void clearDeclarations();
     
     /**
      * Add another base class, must be the pure identifier
@@ -171,7 +171,10 @@ class KDEVPLATFORMLANGUAGE_EXPORT ClassGenerator
     const QList<DeclarationPointer> declarations() const;
     
     /// \return The list of all of the inherited classes
-    const QList<DeclarationPointer> & inheritanceList(void) const;
+    const QList<DeclarationPointer> & inheritanceList() const;
+
+    /// \return The list of directly inherited classes
+    const QList<DeclarationPointer> & directInheritanceList() const;
 
     /**
      *Should return the suggested url of the header file for the given class-name
@@ -207,35 +210,32 @@ class KDEVPLATFORMLANGUAGE_EXPORT ClassGenerator
     /**
      * \return The name of the class to generate (excluding namespaces)
      */
-    const QString & name(void) const;
+    const QString & name() const;
     
     /**
-     * @param identifier The Qualified identifier that the class will have
+     * \param identifier The Qualified identifier that the class will have
      */
-    virtual void identifier(const QString & identifier);
-    
-    /**
-     * \return The class to be generated as a Type
-     */
-    virtual StructureType::Ptr objectType() const = 0;
+    virtual void setIdentifier(const QString & identifier);
     
     /**
      * \return The Identifier of the class to generate (including all used namespaces)
      */
-    virtual QString identifier(void) const;
+    virtual QString identifier() const;
     
-    const QString & license(void) const;
-    void license(const QString & license);
+    const QString & license() const;
+    void setLicense(const QString & license);
+
+    /**
+     * \return The class to be generated as a Type
+     */
+    virtual StructureType::Ptr objectType() const = 0;
 
-    void setAddCommentCharToLicense( bool addcomment );
-    bool addCommentCharToLicense() const;
-    
   protected:
     
     /**
      * Set the name (without namespace) for this class
      */
-    void name(const QString &);
+    void setName(const QString &);
     
     SimpleCursor headerPosition();
     SimpleCursor implementationPosition();
@@ -285,10 +285,6 @@ public:
     virtual ClassIdentifierPage* newIdentifierPage();
 
     virtual OverridesPage* newOverridesPage();
-
-    
-    virtual int nextId() const;
-    
 private:
     friend class OutputPage;
     class CreateClassWizardPrivate* const d;
