@@ -23,6 +23,15 @@ ImportMetadataWidget::ImportMetadataWidget(QWidget *parent)
 
     m_ui->sourceLoc->setEnabled( false );
     m_ui->sourceLoc->setMode( KFile::Directory );
+
+    connect( m_ui->sourceLoc, SIGNAL(textChanged(QString)), SIGNAL(changed()) );
+    connect( m_ui->sourceLoc, SIGNAL(urlSelected(KUrl)), SIGNAL(changed()) );
+    connect( m_ui->comment, SIGNAL(textChanged()), SIGNAL(changed()) );
+    connect( m_ui->module, SIGNAL(userTextChanged(QString)), SIGNAL(changed()) );
+    connect( m_ui->releaseTag, SIGNAL(userTextChanged(QString)), SIGNAL(changed()) );
+    connect( m_ui->repository, SIGNAL(userTextChanged(QString)), SIGNAL(changed()) );
+    connect( m_ui->vendorTag, SIGNAL(userTextChanged(QString)), SIGNAL(changed()) );
+    
 }
 
 ImportMetadataWidget::~ImportMetadataWidget()
@@ -60,4 +69,10 @@ void ImportMetadataWidget::setSourceLocationEditable( bool enable )
     m_ui->sourceLoc->setEnabled( enable );
 }
 
+bool ImportMetadataWidget::hasValidData() const
+{
+    return !m_ui->comment->toPlainText().isEmpty() && !m_ui->sourceLoc->text().isEmpty()
+    && !m_ui->module->text().isEmpty() && !m_ui->repository->text().isEmpty();
+}
+
 #include "importmetadatawidget.moc"
