@@ -111,9 +111,22 @@ NativeAppJob::NativeAppJob(QObject* parent, KDevelop::ILaunchConfiguration* cfg)
     
     proc->setOutputChannelMode(KProcess::MergedChannels);
     
-    proc->setProgram( executable.toLocalFile(), arguments );
+    if (iface->useTerminal(cfg)) {
+        QStringList args = KShell::splitArgs(iface->terminal(cfg));
+        for (QStringList::iterator it = args.begin(); it != args.end(); ++it) {
+            if (*it == "%exe") {
+                *it = executable.toLocalFile();
+            } else if (*it == "%workdir") {
+                *it = wc.toLocalFile();
+            }
+        }
+        args.append( arguments );
+        proc->setProgram( args );
+    } else {
+        proc->setProgram( executable.toLocalFile(), arguments );
+    }
     
-    setTitle(cfg->name());
+    setObjectName(cfg->name());
 }
 
 
@@ -123,7 +136,7 @@ void NativeAppJob::start()
     if( proc )
     {
         startOutput();
-        appendLine( i18n("Starting: %1", proc->property("executable").toString() ) );
+        appendLine( i18n("Starting: %1", proc->program().join(" ") ) );
         proc->start();
     } else
     {
@@ -167,7 +180,7 @@ void NativeAppJob::processError( QProcess::ProcessError error )
     {
         setError( -1 );
         QString errmsg =  i18n("Could not start program '%1'. Make sure that the "
-                           "path is specified correctly.", proc->property("executable").toString() );
+                           "path is specified correctly.", proc->program().join(" ") );
         KMessageBox::error( KDevelop::ICore::self()->uiController()->activeMainWindow(), errmsg, i18n("Could not start application") );
         setErrorText( errmsg );
         emitResult();
