@@ -46,6 +46,8 @@
 #include <interfaces/context.h>
 #include <interfaces/contextmenuextension.h>
 
+#include "../openwith/iopenwith.h"
+
 #include "kdevfilemanagerplugin.h"
 
 FileManager::FileManager(KDevFileManagerPlugin *plugin, QWidget* parent)
@@ -104,7 +106,7 @@ void FileManager::fillContextMenu(KFileItem item, QMenu* menu)
 
 void FileManager::openFile(const KFileItem& file)
 {
-    KDevelop::ICore::self()->documentController()->openDocument( file.url() );
+    KDevelop::IOpenWith::openFiles(KUrl::List() << file.url());
 }
 
 
@@ -115,7 +117,7 @@ void FileManager::gotoUrl( const KUrl& url )
 
 void FileManager::updateNav( const KUrl& url )
 {
-    urlnav->setUrl( url );
+    urlnav->setLocationUrl( url );
 }
 
 void FileManager::setupActions()
