@@ -1,6 +1,7 @@
 /***************************************************************************
  *   Copyright 1999-2001 by Bernd Gehrmann                                 *
  *   bernd@kdevelop.org                                                    *
+ *   Copyright 2010 Julien Desgats <julien.desgats@gmail.com>              *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -17,6 +18,9 @@
 
 #include <QtCore/QVariant>
 
+class KJob;
+class GrepJob;
+
 class GrepViewPlugin : public KDevelop::IPlugin
 {
     Q_OBJECT
@@ -27,12 +31,23 @@ public:
 
     void rememberSearchDirectory(QString const & directory);
     virtual KDevelop::ContextMenuExtension contextMenuExtension(KDevelop::Context* context);
+    void showDialog(bool setLastUsed = false);
     
+    /**
+     * Returns a new instance of GrepJob. Since the plugin supports only one job at the same time,
+     * previous job, if any, is killed before creating a new job.
+     */
+    GrepJob *grepJob();
+
 private Q_SLOTS:
-    void showDialog();
+    void showDialogFromMenu();
+    void showDialogFromProject();
+    void jobFinished(KJob *job);
 
 private:
+    GrepJob *m_currentJob;
     QString m_directory;
+    QString m_contextMenuDirectory;
 };
 
 #endif
