@@ -67,16 +67,7 @@ OpenProjectPage::OpenProjectPage( const KUrl& startUrl, QWidget* parent )
     fileWidget->setMode( KFile::Modes( KFile::File | KFile::Directory | KFile::ExistingOnly ) );
 
     KConfigGroup projectdialogsettings = KGlobal::config()->group( "Open Project Dialog Settings" );
-#if KDE_IS_VERSION(4,3,60)
     fileWidget->readConfig( projectdialogsettings );
-#else
-    projectdialogsettings.writeEntry( "View Style", "Simple" );
-    // Enforce "short view" for now as KFileWidget has no API to read its config from a different
-    // but the global-default for KFileDialog.
-    // TODO for 4.4: Add the needed API to KFileWidget
-    fileWidget->dirOperator()->readConfig( projectdialogsettings );
-    fileWidget->dirOperator()->setViewConfig( projectdialogsettings );
-#endif
 
     layout->addWidget( fileWidget );
 
